#!/bin/sh
# set version number whereever it appears
# Version and Serial Number are taken from Makefile
# unless they are given as parameters

FULLPATH=$(pwd)
CURDIR=$(echo $FULLPATH | sed -e "s|.*/||")
PROGRAMS=timon

if test "$CURDIR" = "bin" ; then
	PATHPREFIX='../'
else
	PATHPREFIX=''
fi

# actual date comes from the system
TODAY=$(date '+%Y-%m-%d')

# Makefile is updated to show the current date
sed -e "/^DATE *=/s/=.*/= $TODAY/" \
    <${PATHPREFIX}Makefile >${PATHPREFIX}Makefile.tmp

if test -s ${PATHPREFIX}Makefile.tmp ; then
	rm -f ${PATHPREFIX}Makefile
	mv ${PATHPREFIX}Makefile.tmp ${PATHPREFIX}Makefile
fi

# authoritative version information is from Makefile
if test -z "$1" ; then
	VERSION=$(cat ${PATHPREFIX}Makefile | sed \
	-e "/^VER *=/!d" -e "s/^VER *= *//")
else
	VERSION=$1
fi

# serial number is taken from the Makefile
if test -z "$2" ; then
	SERIAL=$(cat ${PATHPREFIX}Makefile | sed \
	-e "/^SERIAL *=/!d" -e "s/^SERIAL *= *//")
else
	SERIAL=$2
fi

for PROG in $PROGRAMS ; do
sed -e "/^TI_VERSION=/s/=.*/='$VERSION of $TODAY'/" \
    -e "/^TI_SERIAL=/s/=.*/=$SERIAL/" \
    <${PATHPREFIX}$PROG >${PATHPREFIX}$PROG.tmp

if test -s ${PATHPREFIX}$PROG.tmp ; then
	rm -f ${PATHPREFIX}$PROG
	mv ${PATHPREFIX}$PROG.tmp ${PATHPREFIX}$PROG
	chmod a+x ${PATHPREFIX}$PROG
fi
done

# set version information in the INSTALL file

sed -e "s/timon-[0-9]\\.[0-9][0-9]*\\.[0-9][0-9]*/timon-$VERSION/g" \
    <${PATHPREFIX}INSTALL >${PATHPREFIX}INSTALL.tmp

if test -s ${PATHPREFIX}INSTALL.tmp ; then
	rm -f ${PATHPREFIX}INSTALL
	mv ${PATHPREFIX}INSTALL.tmp ${PATHPREFIX}INSTALL
fi

# set version information in the README file

sed -e "s/timon-[0-9]\\.[0-9][0-9]*\\.[0-9][0-9]*/timon-$VERSION/g" \
    <${PATHPREFIX}README >${PATHPREFIX}README.tmp

if test -s ${PATHPREFIX}README.tmp ; then
	rm -f ${PATHPREFIX}README
	mv ${PATHPREFIX}README.tmp ${PATHPREFIX}README
fi

# set version information in the texi docu

sed -e "s/version .*/version $VERSION/" \
    <${PATHPREFIX}docu/timon_incl.texi \
    >${PATHPREFIX}docu/timon_incl.texi.tmp

if test -s ${PATHPREFIX}docu/timon_incl.texi.tmp ; then
	rm -f ${PATHPREFIX}docu/timon_incl.texi
	mv ${PATHPREFIX}docu/timon_incl.texi.tmp \
	   ${PATHPREFIX}docu/timon_incl.texi
fi

# set version information in the man docu

sed -e "s/xxVERSIONxx/$VERSION/" \
    -e "s/xxDATExx/$TODAY/" \
    <${PATHPREFIX}docu/timon.man.in \
    >${PATHPREFIX}docu/timon.man

exit 0
