#
# this table defines link references between the tables
# on a 'per function' basis
#
# Format is:
# =========
# number		a key, AUTO_INCREMENT	(not really used)
#
# touched		a TIMESTAMP		(not really used)
#
# function		name of function where the link is used
#
# thistable		name of table containing a link;
# 			link is of type INT corresponding to a
#			primary key in othertable
#
# thiscolumn		column in thistable containing a link pointer as data
#
# othertable		table pointed to by thiscolumn
#
# othercolumn		column in othertable which is referenced
#
# otherkey		contains unique key; target of 
#			thiscolumn's link pointer
#
# Example:
#
#  +---------------+
#  | table timelog |
#  +---------------+          +-------------+
#  | number        |          | table staff |
#  +---------------+          +-------------+
#  | staffmember   | -------> | number      |
#  +---------------+          +-------------+
#                             | staffname   |
#                             +-------------+
#

DROP TABLE IF EXISTS links;

#
CREATE TABLE IF NOT EXISTS links (
  number INT NOT NULL DEFAULT 0 AUTO_INCREMENT,
  touched TIMESTAMP,
  shellfunc VARCHAR(255) DEFAULT '' NOT NULL,
  thistable VARCHAR(255) DEFAULT '' NOT NULL,
  thiscolumn VARCHAR(255) DEFAULT '' NOT NULL,
  othertable VARCHAR(255) DEFAULT '' NOT NULL,
  othercolumn VARCHAR(255) DEFAULT '' NOT NULL,
  otherkey VARCHAR(255) DEFAULT '' NOT NULL,
  PRIMARY KEY (number)
) TYPE = MYISAM;


INSERT INTO links VALUES
(NULL,NULL,'editdata','timelog','staffmember','staff','staffname','number'),
(NULL,NULL,'editdata','timelog','staffmember','staff','staffnick','number'),
(NULL,NULL,'editdata','timelog','project','project','casename','number'),
(NULL,NULL,'editdata','timelog','project','project','topic','number'),
(NULL,NULL,'editdata','timelog','jobnumber','jobs','jobdescr','number'),
(NULL,NULL,'editdata','project','principal','address','firm','number'),
(NULL,NULL,'editdata','project','principal','address','firstname','number'),
(NULL,NULL,'editdata','project','principal','address','lastname','number'),
(NULL,NULL,'editdata','project','principal','address','city','number'),
(NULL,NULL,'viewdata','timelog','staffmember','staff','staffname','number'),
(NULL,NULL,'viewdata','timelog','staffmember','staff','staffnick','number'),
(NULL,NULL,'viewdata','timelog','project','project','casename','number'),
(NULL,NULL,'viewdata','timelog','project','project','topic','number'),
(NULL,NULL,'viewdata','timelog','jobnumber','jobs','jobdescr','number'),
(NULL,NULL,'viewdata','project','principal','address','firm','number'),
(NULL,NULL,'viewdata','project','principal','address','firstname','number'),
(NULL,NULL,'viewdata','project','principal','address','lastname','number'),
(NULL,NULL,'viewdata','project','principal','address','city','number'),
(NULL,NULL,'searchdistinct','timelog','staffmember','staff','staffname','number'),
(NULL,NULL,'searchdistinct','timelog','staffmember','staff','staffnick','number'),
(NULL,NULL,'searchdistinct','timelog','project','project','casename','number'),
(NULL,NULL,'searchdistinct','timelog','project','project','topic','number'),
(NULL,NULL,'searchdistinct','timelog','jobnumber','jobs','jobdescr','number'),
(NULL,NULL,'searchdistinct','project','principal','address','firm','number'),
(NULL,NULL,'searchdistinct','project','principal','address','firstname','number'),
(NULL,NULL,'searchdistinct','project','principal','address','lastname','number'),
(NULL,NULL,'searchdistinct','project','principal','address','city','number');
